# CHM13-RRBS methylation comparison for T2T epigenetics paper (Gershman et al.)
The goal in this analysis was to compare Nanopolish methylation calls from CHM13 generated by Ariel Gershman to methylation data (in the form of reduced representation bisulfite sequencing) from early stage embryos. We performed this analysis in order to attempt to "age" the CHM13 cells. My goal was to compare the data.

RRBS data is from:  
Guo, Hongshan, Ping Zhu, Liying Yan, Rong Li, Boqiang Hu, Ying Lian, Jie Yan, et al. 2014. “The DNA Methylation Landscape of Human Early Embryos.” Nature 511 (7511): 606–10. (PMID: [25079557](https://pubmed.ncbi.nlm.nih.gov/25079557/); GEO: [GSE49828](https://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE49828))    

SRA metadata for this project were downloaded from here ("Summary" and "RunInfo" files): https://www.ncbi.nlm.nih.gov/sra?term=SRP028804  

## Scripts to grab list of SRR files to download:
_r\_analysis/gse49828\_files.R_
- R script with which I created a list of all SRR files from the RRBS paper above. SRP for this paper was "SRP028804." It uses the SRAdb (v1.50.0) and DBI (v1.1.0) R packages to download a list of SRA file names associated with a project.  
- The output is a list of SRA files (_r\_analysis/r\_output/GSE49828\_sra\_list.txt_) and SRR files (_r\_analysis/r\_output/GSE49828\_srr\_list.txt_).

## Scripts used to run Bismark:
_rrbs\_bismark/rrbs\_data\_parse.smk_  
_rrbs\_bismark/snakemake\_config.yml_  
- Files for Snakemake scripts that run the following pipeline on downloaded RRBS data:
	- Trimming adaptors from reads using TrimGalore v0.6.6 according to [Bismark author's recommendations for RRBS data](https://github.com/FelixKrueger/Bismark/tree/master/Docs). This mainly includes the options `--paired` and `--rrbs`  
	- Preparing the genome (in this case T2T CHM13 genome) for [Bismark](https://github.com/FelixKrueger/Bismark) (v0.22.2) alignment. Uses the Bismark command `bismark_genome_preparation` with the option `--verbose`  
	- Aligning the trimmed paired-end reads to the T2T CHM13 reference genome using [Bismark](https://github.com/FelixKrueger/Bismark) (v0.22.2).Uses the `bismark` command  with the following parameters: `--bam --bowtie --genome <genome> -p --basename <basename> -1 <R1> -2 <R2> --temp_dir <temp dir> --output_dir <output dir>`  
	- Extracting methylation from alignments using [Bismark](https://github.com/FelixKrueger/Bismark) (v0.22.2). Uses the Bismark command `bismark\_methylation\_extractor` with the following key parameters: `-p --comprehensive --merge_non_CpG -o <out dir> --bedGraph --gzip --remove_spaces --cytosine_report --genome_folder <genome folder>`  
- The Snakemake uses a list of files as input so it only analyzes the bulk RRBS data from this paper. This file is _rrbs\_bismark/rrbs\_samples.txt_. It was derived from the metadata downloaded from SRA.   

## Script used to manually re-call methylation with Bismark in order to combine technical replicates:
_rrbs\_bismark/methylation\_processing.sh_  
- In this script, I had to manually set up [Bismark](https://github.com/FelixKrueger/Bismark) methylation extraction commands so I could combine the technical replicates. Since I did that, I went ahead and re-called all non-technical replicate samples so the output files names would become the sample names. The sample names follow the format found in the meta data downloaded from SRA.
- The basic Bismark methylation extraction re-call in this case was: 
```bash
~/software/Bismark-0.22.2/bismark2bedGraph -o <sample_name>_cpg.bedgraph.gz \
--buffer_size 20G \
--remove_spaces \
--dir processed_meth_calls \
CpG_context_<SRRfile1>_bismark_bt2_pe.txt.gz CpG_context_<SRRfile2>_bismark_bt2_pe.txt.gz
``` 
## Code used to make clean metadata for all the samples
_r\_analysis/meta\_processing.Rmd_
- This script uses metadata downloaded from SRA (specifically the "Summary" file) to make a nice metadata to be used later.  

## Code used to compare and produce plots for CHM13 and RRBS methylation
_r\_analysis/final_chm13.rrbs.Rmd_  
- This is the RMarkdown that contains the actual analysis of the data. The main steps are:   
	- Reading in the data with the `read.bismark` command from the [bsseq](https://www.bioconductor.org/packages/release/bioc/html/bsseq.html) package. Data was read in for T2T reference CHM13 CpGs only.     
	- Filtering for loci where 90% of the samples have a coverage of at least 1 read 
	- Calculating Euclidean distance between samples using raw methylation percentages and clustering.
- Dendrogram plot (_r\_analysis/r\_output/210428\_dendro\_gg.pdf_) was produced.   
- R version 4.0.2. Primary R packages used: ggcorrplot (v0.1.3), BSgenome.t2t.v1.0.release_1.0, bsseq (v1.24.4), BiocParallel (v1.22.0), GenomicRanges (v1.40.0), tidyverse (v1.3.0)

## One liners that were used and that may be of interest
- Downloading GSE49828 data from SRA:
```bash
# fastq-dump v2.8.0
fastq-dump --outdir . --gzip --split-3 $(<GSE49828_srr_list.txt)
```
- Converting Nanopolish output to something that looks like Bismark .cov file output:
```bash
cat methylation_frequency_50kb_split.tsv | tail -n +2 | awk 'BEGIN{FS="\t";OFS="\t"}{print $1,$2+1,$3+1,$7,$6,$5}' > all_readlengths/chm13_rrbs_meth.cov
```

